Annealing Data Base

# Info on Annealing Data Base

    1. Title of Database: Annealing Data

    2. Source Information: donated by David Sterling and Wray Buntine.

    3. Past Usage: unknown

    4. Relevant Information:
       -- Explanation: I suspect this was left by Ross Quinlan in 1987 at the
          4th Machine Learning Workshop.  I'd have to check with Jeff Schlimmer
          to double check this.

    5. Number of Instances: 798

    6. Number of Attributes: 38
       -- 6 continuously-valued
       -- 3 integer-valued
       -- 29 nominal-valued

    7. Attribute Information:
        1. family:		--,GB,GK,GS,TN,ZA,ZF,ZH,ZM,ZS
        2. product-type:	C, H, G
        3. steel:		-,R,A,U,K,M,S,W,V
        4. carbon:		continuous
        5. hardness:	continuous
        6. temper_rolling:	-,T
        7. condition:	-,S,A,X
        8. formability:	-,1,2,3,4,5
        9. strength:	continuous
       10. non-ageing:	-,N
       11. surface-finish:	P,M,-
       12. surface-quality: -,D,E,F,G
       13. enamelability:	-,1,2,3,4,5
       14. bc:		Y,-
       15. bf:		Y,-
       16. bt:		Y,-
       17. bw/me:		B,M,-
       18. bl:		Y,-
       19. m:		Y,-
       20. chrom:		C,-
       21. phos:		P,-
       22. cbond:		Y,-
       23. marvi:		Y,-
       24. exptl:		Y,-
       25. ferro:		Y,-
       26. corr:		Y,-
       27. blue/bright/varn/clean:		B,R,V,C,-
       28. lustre:		Y,-
       29. jurofm:		Y,-
       30. s:		Y,-
       31. p:		Y,-
       32. shape:		COIL, SHEET
       33. thick:		continuous
       34. width:		continuous
       35. len:		continuous
       36. oil:		-,Y,N
       37. bore:		0000,0500,0600,0760
       38. packing:	-,1,2,3
       classes:        1,2,3,4,5,U

       -- The '-' values are actually 'not_applicable' values rather than
          'missing_values' (and so can be treated as legal discrete
          values rather than as showing the absence of a discrete value).

    8. Missing Attribute Values: Signified with "?"
       Attribute:  Number of instances missing its value:
       1           0
       2           0
       3           70
       4           0
       5           0
       6           675
       7           271
       8           283
       9           0
      10           703
      11           790
      12           217
      13           785
      14           797
      15           680
      16           736
      17           609
      18           662
      19           798
      20           775
      21           791
      22           730
      23           798
      24           796
      25           772
      26           798
      27           793
      28           753
      29           798
      30           798
      31           798
      32           0
      33           0
      34           0
      35           0
      36           740
      37           0
      38           789
      39           0

    9. Distribution of Classes
         Class Name:   Number of Instances:
         1               8
         2              88
         3             608
         4               0
         5              60
         U              34
                       ---
                       798